program define winsor
sum `1', d
replace `1'=r(p1) if `1'<r(p1) & `1'!=.
replace `1'=r(p99) if `1'>r(p99) &`1'!=. 
end

*Datasets
*"crsp2014.dta" is CRSP monthly file
*"daily.dta" is CRSP daily file
*"options.dta" is OptionMetrics
*"EAcompustat2015-downloadAUG2015.dta" is CRSP-Compustat merged database - Quarterly
*"IBESdetails-unadjustedq" is IBES detail file - unadjusted
*"actuals_unadjustedq" IS IBES actuals unadjusted
************************************************************************************
*Construct intermediate databases
************************************************************************************

*Recover permnos and adjustment factors from CRSP, to be merged below with IBES data
use cfacshr ncusip date permno using "../data/daily.dta", clear
*From CRSPDaily, complete for days without trading
drop if missing(ncusip)
sort ncusip date
bysort ncusip: gen d=date[_n+1]-date if ncusip[_n+1]==ncusip
save t, replace
forvalues i=2(1)8{
keep if d==`i'
replace date=date+d-1
append using t
save t, replace
}
drop d
duplicates drop
rename ncusip cusip
save t, replace

use permno ncusip date cfacshr prc using "../data/crsp2014.dta", clear
rename ncusip cusip
drop if missing(cusip)
gen m=month(date)
gen y=year(date)
gen mnumber=12*(y-1990)+m
replace prc=abs(prc)
rename cfacshr cfacshrmonthly
keep cusip mnumber prc permno cfacshrmonthly
sort permno mnumber
bysort permno: gen prc_1=prc[_n-12] if mnumber==mnumber[_n-12]+12
keep permno mnumber prc_1 cfacshrmonthly
save t2.dta, replace

*Construct IMPLIEDVOL, the average over the previous 12 months of 30-day implied volatility of all at-the-money options for a given stock.
use "../Data/options.dta", clear
joinby cusip date using t
keep if days==30
gen monthn=12*(year(date)-1990)+month(date)
keep impl_volatility monthn permno
keep if impl_volatility>0
save options30, replace

clear
cap quietly use if monthn>=81&monthn<=92 using options30, replace
cap quietly bysort permno: egen impliedvol3012=mean(impl_volatility) 
cap quietly keep if monthn==92
cap quietly by permno: keep if _n==1
save t3012, replace
forvalues i=93(1)296{
disp `i'
cap quietly use if monthn>=`i'-11&monthn<=`i' using options30, replace
cap quietly bysort permno: egen impliedvol3012=mean(impl_volatility)  
cap quietly keep if monthn==`i'
cap quietly by permno: keep if _n==1
cap quietly
append using t3012
cap quietly save t3012, replace
}


*Confirming EA dates, rdq is quarterly announcement date from Compustat. 
use database lpermno rdq fqtr using ../data/EAcompustat2015-downloadAUG2015.dta, clear
gen monthnq=12*(year(datadate)-1990)+month(datadate)
gen t=12*(year(datadate)-1990)+month(datadate) if fqtr==4
bysort lpermno fyear: egen monthn=max(t)
drop t
rename lpermno permno
bysort permno monthnq: keep if _n==1
keep permno monthn monthnq rdq fqtr
save rdq, replace


*Start from IBES actuals database, merge with quarterly announcement dates from Compustat.
*Below, when quarterly announcement dates are available in both Compustat and IBES, we take the earlier date
use pdicity cusip pends anndats using ../data/actuals_unadjustedq.dta, clear
drop if missing(cusip)
rename pends date
joinby cusip date using t
rename date datadateq
gen monthnq=12*(year(datadateq)-1990)+month(datadateq)
joinby permno monthnq using rdq
keep if pdicity=="QTR"|pdicity=="ANN"
drop if fqtr==4&pdicity=="QTR"
gen anndatsea=min(anndats,rdq) if !missing(anndats)&!missing(rdq)
replace anndatsea=rdq if missing(anndats)&!missing(rdq)
replace anndatsea=anndats if !missing(anndats)&missing(rdq)
keep monthnq anndats* rdq value permno monthn datadateq cusip fqtr
bysort permno monthn cusip fqtr: gen a=_n
keep if a==1
drop a monthnq
reshape wide datadateq anndats* rdq value, i(permno monthn cusip) j(fqtr)
save eadate, replace


* store value of the annual earnings
use pends value pdicity cusip using ../data/actuals_unadjustedq.dta, clear
rename pends fpedats
rename value valueact
drop if missing(cusip)
keep if pdicity=="ANN"
keep cusip fpedats valueact
save actual, replace

*Compute analysts' forecasts revisions and forecast dispersion


use "../data/IBESdetails-unadjustedq.dta", clear
*Use IBES and keep observations with non-missing information on analyst id, cusip.
drop if analys==0|missing(analys)
drop if missing(cusip)

*Keep forecasts of annual earnings only
keep if fpi=="1"|fpi=="2"

*recover permno, and crsp adjustment factors
rename anndats date
joinby cusip date using t
gen mnumber=12*(year(fpedats)-1990)+month(fpedats)
joinby permno mnumber using t2
rename mnumber monthn

*analysts' forecasts are adjusted for stock-splits with CRSP cumulative adjustment factor
gen valueadj=(value*cfacshrmonthly)/cfacshr
drop if missing(valueadj)
joinby cusip fpedats using actual, unm(b)
drop if _merge==2
drop _merge
joinby permno monthn using eadate, unm(b)
drop if _merge==2
drop _merge
bysort permno analys date fpi: keep if _n==1
save ibestemp.dta, replace



*Compute analyst coverage (used as a control in regressions)
use ibestemp.dta, clear
keep if fpi=="1"
gen fe=abs(valueadj-valueact)
gen bias=valueadj-valueact
rename date anndats
gen monthnf=12*(year(anndats)-1990)+month(anndats)
drop if missing(anndats)|missing(fpedats)
sort analys permno fpedats anndats
bysort analys permno fpedats: keep if _n==_N
gen n=1
bysort permno fpedats: egen anal=sum(n)
bysort permno monthn: keep if _n==1
sort permno monthn
keep anal permno monthn prc_1 fpedats
save coverage, replace

use ibestemp.dta, clear
bysort permno fpedats: keep if _n==1
keep anndatsea2 anndatsea3 anndatsea4 permno monthn value4
rename value4 value4l
rename anndatsea4 anndatsea4l
rename anndatsea3 anndatsea3l
rename anndatsea2 anndatsea2l
replace monthn=monthn+12
save lag, replace

*Forecasts' Dispersion measure, constructed first separately for each quarter, and then merged together
use ibestemp.dta, clear
keep if fpi=="1"
gen fe=abs(valueadj-valueact)
gen bias=valueadj-valueact
rename date anndats
gen monthnf=12*(year(anndats)-1990)+month(anndats)
drop if missing(anndats)|missing(fpedats)

*Keep for each analyst, the last forecast made between two consecutive quarterly earnings announcements
drop if anndats>anndatsea4
drop if anndats<anndatsea3
drop if missing(anndatsea4)|missing(anndatsea3)
sort analys permno fpedats anndats
bysort analys permno fpedats: keep if _n==_N
gen n=1
bysort permno fpedats: egen disp=sd(valueadj)
replace disp=disp/abs(prc_1)
bysort permno monthn: keep if _n==1
sort permno monthn
keep permno cusip fpedats monthn disp value4 valueact
gen fqtr=4
save disp.dta, replace


use ibestemp.dta, clear
keep if fpi=="1"
rename date anndats
gen monthnf=12*(year(anndats)-1990)+month(anndats)
drop if missing(anndats)|missing(fpedats)
drop if anndats>anndatsea3
drop if anndats<anndatsea2
drop if missing(anndatsea3)|missing(anndatsea2)
sort analys permno fpedats anndats
bysort analys permno fpedats: keep if _n==_N
gen n=1
bysort permno fpedats: egen disp=sd(valueadj)
replace disp=disp/abs(prc_1)

bysort permno monthn: keep if _n==1
sort permno monthn
keep permno cusip fpedats monthn disp value4 valueact
gen fqtr=3
append using disp
save disp.dta, replace

use ibestemp.dta, clear
keep if fpi=="1"
rename date anndats
gen monthnf=12*(year(anndats)-1990)+month(anndats)
drop if missing(anndats)|missing(fpedats)
drop if anndats>anndatsea2
drop if anndats<anndatsea1
drop if missing(anndatsea2)|missing(anndatsea1)
sort analys permno fpedats anndats
bysort analys permno fpedats: keep if _n==_N
gen n=1
bysort permno fpedats: egen disp=sd(valueadj)
replace disp=disp/abs(prc_1)
bysort permno monthn: keep if _n==1
sort permno monthn
keep permno cusip fpedats monthn disp value4 valueact
gen fqtr=2
append using disp
save disp.dta, replace

use ibestemp.dta, clear
keep if fpi=="1"
*recover announcement date of previous fiscal year Q4 earnings
joinby permno monthn using lag
rename date anndats
gen monthnf=12*(year(anndats)-1990)+month(anndats)
drop if missing(anndats)|missing(fpedats)
drop if anndats>anndatsea1
drop if anndats<anndatsea4l
drop if missing(anndatsea4l)|missing(anndatsea1)
sort analys permno fpedats anndats
bysort analys permno fpedats: keep if _n==_N
gen n=1
bysort permno fpedats: egen disp=sd(valueadj)
replace disp=disp/abs(prc_1)
bysort permno monthn: keep if _n==1
sort permno monthn
keep permno cusip fpedats monthn disp value4 valueact
gen fqtr=1
append using disp
save disp.dta, replace

*Forecasts' Revisions

*For each analyst and fiscal year, keep the last forecast for each fiscal quarter
use ibestemp.dta, clear
joinby permno monthn using lag, unm(b)
drop if _merge==2
gen fe=abs(valueadj-value4)
rename date anndats
gen monthnf=12*(year(anndats)-1990)+month(anndats)
drop if missing(anndats)|missing(fpedats)
drop if anndats>fpedats
gen valueadj4l=valueadj if anndats<anndatsea4l
gen valueadj4lb=valueadj if anndats<anndatsea4l&anndatsea3l<anndats
gen valueadj1=valueadj if anndats<anndatsea1
gen valueadj1b=valueadj if anndats<anndatsea1&anndatsea4l<anndats
gen valueadj2=valueadj if anndats<anndatsea2
gen valueadj2b=valueadj if anndats<anndatsea2&anndatsea1<anndats
gen valueadj3=valueadj if anndats<anndatsea3
gen valueadj3b=valueadj if anndats<anndatsea3&anndatsea2<anndats
gen valueadj4=valueadj if anndats<anndatsea4
gen valueadj4b=valueadj if anndats<anndatsea4&anndatsea3<anndats
save temp, replace

use temp, clear
drop if missing(valueadj1)
sort analys permno fpedats anndats
bysort analys permno fpedats: keep if _n==_N
keep analys permno fpedats valueadj1 value4 value4l
save temp2, replace

foreach var in valueadj1b valueadj2 valueadj2b valueadj3 valueadj3b valueadj4 valueadj4b valueadj4l valueadj4lb{
use temp, clear
drop if missing(`var')
sort analys permno fpedats anndats
bysort analys permno fpedats: keep if _n==_N
keep analys permno fpedats `var' value4 value4l
joinby analys permno fpedats using temp2, unm(b)
drop _merge
save temp2, replace
}



use temp2, clear

gen revq1=valueadj1b-valueadj4l if !missing(valueadj1b)&!missing(valueadj4l)
gen revq2=valueadj2b-valueadj1 if !missing(valueadj2b)&!missing(valueadj1)
gen revq3=valueadj3b-valueadj2 if !missing(valueadj3b)&!missing(valueadj2)
gen revq4=valueadj4b-valueadj3 if !missing(valueadj4b)&!missing(valueadj3)


forvalues i=1(1)4{
gen posrevq`i'=(revq`i'>0)&!missing(revq`i')
replace posrevq`i'=. if missing(revq`i')
gen negrevq`i'=(revq`i'<0)&!missing(revq`i')
replace negrevq`i'=. if missing(revq`i')
}
gen monthn=12*(year(fpedats)-1990)+month(fpedats)
gen year=year(fpedats)
keep permno monthn revq* posrevq* negrevq* analys year valueadj*
save revanaltemp, replace

use revanaltemp, clear
keep year permno monthn revq1 posrevq1 negrevq1 analys 
rename revq1 revq
rename posrevq1 posrevq
rename negrevq1 negrevq
gen fqtr=1
save revanal, replace

forvalues i=2(1)4{
use revanaltemp, clear
keep year permno monthn revq`i' posrevq`i' negrevq`i' analys 
rename revq`i' revq
rename posrevq`i' posrevq
rename negrevq`i' negrevq
gen fqtr=`i'
append using revanal
save revanal, replace
}

use revanal, clear
egen g=group(year fqtr)
sort permno analys g
*Construct lagged values of analysts' forecast revisions
bysort permno analys: gen posrevq_1=1 if (posrevq[_n-1]==1)&(g[_n-1]==g[_n]-1)
bysort permno analys: gen negrevq_1=1 if negrevq[_n-1]==1&(g[_n-1]==g-1)
bysort permno analys: replace posrevq_1=0 if posrevq[_n-1]==0&(g[_n-1]==g-1)
bysort permno analys: replace negrevq_1=0 if negrevq[_n-1]==0&(g[_n-1]==g-1)
drop g year
save revanal, replace


*Construct our measures of earnings surprises
use ../data/EAcompustat2015-downloadAUG2015.dta, clear
gen roa=oibdpq/atq
rename lpermno permno
bysort permno datadate: keep if _n==1

gen year=year(datadate)
gen month=month(datadate)

gen monthn=12*(year(datadate)-1990)+month(datadate)
replace month=3 if month==1|month==2
replace month=6 if month==4|month==5
replace month=9 if month==7|month==8
replace month=12 if month==10|month==11

gen monthn2=12*(year-1990)+month
gen qn=int(monthn2/3)
bysort permno qn: keep if _n==1
bysort permno fyearq: gen a=_N
keep if a==4
sort permno fyearq fqtr

destring permno, replace
tsset permno qn

*We use earnings per share before extraordinary items (epspxq), which are then split-adjusted (using variable ajexq)
replace epspxq=epspxq/ajexq

sum qn
local start=_result(5)+12
local end=_result(6)
gen c=.
gen sigma=.
gen nbobs=.



*SUE is defined as in Sadka (2006) (c is the drift)

forvalues i=`start'(1)`end'{
local pct=int(100*((`i'-`start')/(`end'-`start'))*10)/10
disp "`1' `2' `pct'% complete"
gen x=!missing(epspxq) if (qn>=`i'-8)&(qn<=`i'-1)
bysort gvkey: egen sumx=sum(x)
gen y=epspxq-epspxq[_n-4] if (qn>=`i'-8)&(qn<=`i'-1)
bysort permno: egen sumy=mean(y)
bysort permno: egen sdy=sd(y)
replace nbobs=sumx if qn==`i'
replace c=sumy if qn==`i'
replace sigma=sdy if qn==`i'
drop sumx sumy sdy x y
}
sort permno qn
bysort permno: gen sue=epspxq-epspxq[_n-4]-c if qn[_n-4]==qn-4
gen adsue=sue/sigma
gen sign_sue=sue>0&!missing(sue)
replace sign_sue=. if missing(sue)|nbobs~=8
replace adsue=. if missing(sue)|nbobs~=8
replace sue=. if nbobs~=8
foreach var of varlist sign_sue sue adsue{
gen L`var'=L.`var'
gen LL`var'=L.L.`var'
gen LLL`var'=L.L.L.`var'
}
gen LLsign_suen=1-LLsign_sue
gen Lsign_suen=1-Lsign_sue
gen LLLsign_suen=1-LLLsign_sue
keep permno gvkey monthn fyearq fqtr qn sign* sue* L* adsue* sic roa
gen minsign=min(Lsign_sue,LLsign_sue,LLLsign_sue)
gen maxsign=max(Lsign_sue,LLsign_sue,LLLsign_sue)
gen same=minsign==maxsign
replace same=. if missing(minsign)
gen change=1-same
gen mintemp=min(LLsign_sue,Lsign_sue)
gen maxtemp=max(LLsign_sue,Lsign_sue)
gen same2=mintemp==maxtemp
replace same2=. if missing(mintemp)
gen change2=1-same2
gen pos=max(LLsign_sue,LLLsign_sue)
gen neg=1-min(LLsign_sue,LLLsign_sue)
replace pos=. if missing(LLsign_sue)|missing(LLLsign_sue)
replace neg=. if missing(LLsign_sue)|missing(LLLsign_sue)
drop min* max* 
gen m=monthn if fqtr==4
bysort permno fyearq: egen mm=max(m)
drop monthn m
rename mm monthn
save rollingeps, replace

*Construct full sample
use coverage, clear

*SUEs
joinby permno monthn using rollingeps, unm(b)
drop if _merge==2
drop _merge

*Analysts' forecast revisions
joinby permno monthn fqtr using revanal, unm(b)
drop if _merge==2
drop _merge

*Dispersion of analysts forecasts
joinby permno monthn fqtr using disp, unm(b)
drop if _merge==2
drop _merge


* Merge with control variables computed at the end of the fiscal year
*******************************************************************

*Implied volatility
joinby permno monthn using t3012, unm(b)
drop if _merge==2
drop _merge

*Book-to-market defined as in Fama and French (2008)
joinby permno monthn using BEME, unm(b)
drop if _merge==2
drop _merge

*volret is the standard deviation of daily raw returns of the stock in the current fiscal year, built from CRSP daily file
joinby permno monthn using volret, unm(b)
drop if _merge==2
drop _merge

*Construct famafrench industries
destring sic, replace
do famafrench

*Size is ln(csho*prcc_f) from compustat
joinby permno monthn using sizecontrol, unm(b)
drop if _merge==2
drop _merge


foreach var in disp adsue Ladsue LLadsue LLLadsue anal roa size volret lnbm impliedvol3012{  
winsor `var'
}


gen revsignsue=posrevq if Ladsue>0
replace revsignsue=negrevq if Ladsue<0

gen LLadsueabs=abs(LLadsue)
gen Ladsueabs=abs(Ladsue)

*Exclude observations with stock price lower than $5
drop if abs(prc_1)<=5
drop if missing(prc_1)

bysort permno monthn fqtr analys: keep if _n==1
drop if missing(revsignsue)|missing(disp)|missing(size)|missing(anal)|missing(lnbm)|missing(volret)|missing(roa)|missing(adsue)|missing(Ladsue)|missing(LLadsue)|missing(LLLadsue)

*Label variables

label variable disp "DISP"
label variable anal "COVERAGE"
label variable volret "SIGMA"
label variable lnbm "LNBM"
label variable size "LN(MKTCAP)"
label variable roa "ROA"
label variable Ladsueabs "ABS SUE(Q-1)"

label variable neg "NEG SUE(Q-2,Q-3)"
label variable pos "POS SUE(Q-2,Q-3)"
label variable change "SUE SIGN CHANGE(Q-1,Q-2,Q-3)"
label variable change2 "SUE SIGN CHANGE(Q-1,Q-2)"
label variable LLsign_sue "POS SUE(Q-2)"
label variable LLsign_suen "NEG SUE(Q-2)"
label variable posrevq_1 "POSREV(Q-1)"
label variable negrevq_1 "NEGREV(Q-1)"
bysort permno qn: gen a=_n
replace disp=100*disp


gen treat=1 if (Lsign_suen==1&posrevq_1==1)
replace treat=1 if (Lsign_sue==1&negrevq_1==1)
replace treat=0 if missing(treat)
replace treat=. if missing(posrevq_1)
replace treat=. if missing(negrevq_1)

save base, replace



use base, clear


**************************Summary statistics*********************************
eststo clear
estpost summarize posrevq negrevq revsignsue, detail
esttab using table1.tex, cells("count mean(fmt(3)) sd(fmt(3)) p10(fmt(3)) p50(fmt(3)) p90(fmt(3))") noobs nonumber label title("Summary statistics") replace
eststo clear
estpost summarize disp Ladsue Ladsueabs LLsign_sue pos change change2 treat anal size volret impliedvol3012 lnbm roa if a==1, detail
esttab using table1.tex, cells("count mean(fmt(3)) sd(fmt(3)) p10(fmt(3)) p50(fmt(3)) p90(fmt(3))") noobs nonumber label title("Summary statistics") append


**************************Tables**********************************************

eststo clear
eststo: xi: areg revsignsue change2 Ladsueabs size anal volret lnbm roa i.qn i.fqtr, a(analys) cl(permno)
eststo: xi: areg revsignsue change2 Ladsueabs size anal volret lnbm roa i.qn i.fqtr i.famafrench, a(analys) cl(permno)
eststo: xi: reg2hdfe revsignsue change2 Ladsueabs size anal volret lnbm roa i.qn i.fqtr, id1(permno) id2(analys) maxiter(5) cluster(permno)
eststo: xi: areg revsignsue change Ladsueabs size anal volret lnbm roa i.qn i.fqtr, a(analys) cl(permno)
eststo: xi: areg revsignsue change Ladsueabs size anal volret lnbm roa i.qn i.fqtr i.famafrench, a(analys) cl(permno)
eststo: xi: reg2hdfe revsignsue change Ladsueabs size anal volret lnbm roa i.qn i.fqtr, id1(permno) id2(analys) maxiter(5) cluster(permno)
esttab using table2.tex, se r2 nolines nogaps nomtitles noconst label b(%5.3f) se(%5.3f) append keep(change2 change Ladsueabs size anal volret lnbm roa) order(change2 change Ladsueabs size anal volret lnbm roa) ///
prehead(\begin{table}\caption{FORECAST REVISION}\begin{scriptsize} ///
\begin{center}\begin{tabular}{l*{6}{c}}\hline&&&&&&\\&\multicolumn{6}{c}{REVISION IN THE SAME DIRECTION AS THE LATEST SUE}\\&[1]&[2]&[3]&[4]&[5]&[6]\\\cmidrule(lr){2-4}\cmidrule(lr){5-7} &&&&&&\\) ///
prefoot(&&&&&& \\ "Fiscal-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Year-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Analyst FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Industry FE & No & Yes & No & No & Yes & No \\" "Stock FE & No & No & Yes & No & No & Yes \\" &&&&&&\\)  ///
postfoot(&&&&&& \\ \hline  "\end{tabular} \end{center} \end{footnotesize} \end{table}\newpage")starlevels("$^{*}$" 0.10 "$^{**}$" 0.05 "$^{***}$" 0.01)alignment(D{.}{.}{-1}) page(dcolumn) nonumber


eststo clear
eststo: xi: areg revsignsue change2 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr, a(analys) cl(permno)
eststo: xi: areg revsignsue change2 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr i.famafrench, a(analys) cl(permno)
eststo: xi: reg2hdfe revsignsue change2 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr, id1(permno) id2(analys) maxiter(5) cluster(permno)
eststo: xi: areg revsignsue change Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr, a(analys) cl(permno)
eststo: xi: areg revsignsue change Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr i.famafrench, a(analys) cl(permno)
eststo: xi: reg2hdfe revsignsue change Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr, id1(permno) id2(analys) maxiter(5) cluster(permno)
esttab using table3.tex, se r2 nolines nogaps nomtitles noconst label b(%5.3f) se(%5.3f) append keep(change2 change Ladsueabs size anal impliedvol3012w lnbm roa) order(change2 change Ladsueabs size anal impliedvol3012w lnbm roa) ///
prehead(\begin{table}\caption{FORECAST REVISION - ROBUSTNESS}\begin{scriptsize} ///
\begin{center}\begin{tabular}{l*{6}{c}}\hline&&&&&&\\&\multicolumn{6}{c}{REVISION IN THE SAME DIRECTION AS THE LATEST SUE}\\&[1]&[2]&[3]&[4]&[5]&[6]\\\cmidrule(lr){2-4}\cmidrule(lr){5-7} &&&&&&\\) ///
prefoot(&&&&&& \\ "Fiscal-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Year-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Analyst FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Industry FE & No & Yes & No & No & Yes & No \\" "Stock FE & No & No & Yes & No & No & Yes \\" &&&&&&\\)  ///
postfoot(&&&&&& \\ \hline  "\end{tabular} \end{center} \end{footnotesize} \end{table}\newpage")starlevels("$^{*}$" 0.10 "$^{**}$" 0.05 "$^{***}$" 0.01)alignment(D{.}{.}{-1}) page(dcolumn) nonumber


eststo clear
eststo: xi: areg posrevq LLsign_suen Ladsueabs size anal volret lnbm roa i.qn i.fqtr if Lsign_sue2_epspxq==1, a(analys) cl(permno)
eststo: xi: areg posrevq LLsign_suen Ladsueabs size anal volret lnbm roa i.qn i.fqtr i.famafrench if Lsign_sue2_epspxq==1, a(analys) cl(permno)
eststo: xi: reg2hdfe posrevq LLsign_suen Ladsueabs size anal volret lnbm roa i.qn i.fqtr if Lsign_sue2_epspxq==1, id1(permno) id2(analys) maxiter(5) cluster(permno)
eststo: xi: areg posrevq neg2_epspxq Ladsueabs size anal volret lnbm roa i.qn i.fqtr if Lsign_sue2_epspxq==1, a(analys) cl(permno)
eststo: xi: areg posrevq neg2_epspxq Ladsueabs size anal volret lnbm roa i.qn i.fqtr i.famafrench if Lsign_sue2_epspxq==1, a(analys) cl(permno)
eststo: xi: reg2hdfe posrevq neg2_epspxq Ladsueabs size anal volret lnbm roa i.qn i.fqtr if Lsign_sue2_epspxq==1, id1(permno) id2(analys) maxiter(5) cluster(permno)
esttab using table4.tex, se r2 nolines nogaps nomtitles noconst label b(%5.3f) se(%5.3f) append keep(LLsign_suen neg2_epspxq Ladsueabs size anal volret lnbm roa) order(LLsign_suen neg2_epspxq Ladsueabs size anal volret lnbm roa) ///
prehead(\begin{table}\caption{ POSITIVE REVISION}\begin{scriptsize} ///
\begin{center}\begin{tabular}{l*{6}{c}}\hline&&&&&&\\&\multicolumn{6}{c}{POSREV(Q) (Sample with SUE(Q-1)>0 only)}\\&[1]&[2]&[3]&[4]&[5]&[6]\\\cmidrule(lr){2-4}\cmidrule(lr){5-7} &&&&&&\\) ///
prefoot(&&&&&& \\ "Fiscal-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Year-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Analyst FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Industry FE & No & Yes & No & No & Yes & No \\" "Stock FE & No & No & Yes & No & No & Yes \\" &&&&&&\\)  ///
postfoot(&&&&&& \\ \hline  "\end{tabular} \end{center} \end{footnotesize} \end{table}\newpage")starlevels("$^{*}$" 0.10 "$^{**}$" 0.05 "$^{***}$" 0.01)alignment(D{.}{.}{-1}) page(dcolumn) nonumber


eststo clear
eststo: xi: areg negrevq LLsign_sue Ladsueabs size anal volret lnbm roa i.qn i.fqtr if Lsign_sue2_epspxq==0, a(analys) cl(permno)
eststo: xi: areg negrevq LLsign_sue Ladsueabs size anal volret lnbm roa i.qn i.fqtr i.famafrench if Lsign_sue2_epspxq==0, a(analys) cl(permno)
eststo: xi: reg2hdfe negrevq LLsign_sue Ladsueabs size anal volret lnbm roa i.qn i.fqtr if Lsign_sue2_epspxq==0, id1(permno) id2(analys) maxiter(5) cluster(permno)
eststo: xi: areg negrevq pos Ladsueabs size anal volret lnbm roa i.qn i.fqtr if Lsign_sue2_epspxq==0, a(analys) cl(permno)
eststo: xi: areg negrevq pos Ladsueabs size anal volret lnbm roa i.qn i.fqtr i.famafrench if Lsign_sue2_epspxq==0, a(analys) cl(permno)
eststo: xi: reg2hdfe negrevq pos Ladsueabs size anal volret lnbm roa i.qn i.fqtr if Lsign_sue2_epspxq==0, id1(permno) id2(analys) maxiter(5) cluster(permno)
esttab using table5.tex, se r2 nolines nogaps nomtitles noconst label b(%5.3f) se(%5.3f) append keep(LLsign_sue pos Ladsueabs size anal volret lnbm roa) order(LLsign_sue pos Ladsueabs size anal volret lnbm roa) ///
prehead(\begin{table}\caption{ NEGATIVE REVISION}\begin{scriptsize} ///
\begin{center}\begin{tabular}{l*{6}{c}}\hline&&&&&&\\&\multicolumn{6}{c}{NEGREV(Q) (Sample with SUE(Q-1)<0 only)}\\&[1]&[2]&[3]&[4]&[5]&[6]\\\cmidrule(lr){2-4}\cmidrule(lr){5-7} &&&&&&\\) ///
prefoot(&&&&&& \\ "Fiscal-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Year-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Analyst FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Industry FE & No & Yes & No & No & Yes & No \\" "Stock FE & No & No & Yes & No & No & Yes \\" &&&&&&\\)  ///
postfoot(&&&&&& \\ \hline  "\end{tabular} \end{center} \end{footnotesize} \end{table}\newpage")starlevels("$^{*}$" 0.10 "$^{**}$" 0.05 "$^{***}$" 0.01)alignment(D{.}{.}{-1}) page(dcolumn) nonumber

eststo clear
eststo: xi: areg revsignsue treat posrevq_1 Ladsueabs size anal volret lnbm roa i.qn i.fqtr, a(analys) cl(permno)
eststo: xi: areg revsignsue treat posrevq_1 Ladsueabs size anal volret lnbm roa i.qn i.fqtr i.famafrench, a(analys) cl(permno)
eststo: xi: reg2hdfe revsignsue treat posrevq_1 Ladsueabs size anal volret lnbm roa i.qn i.fqtr, id1(permno) id2(analys) maxiter(5) cluster(permno)
eststo: xi: areg revsignsue treat posrevq_1 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr, a(analys) cl(permno)
eststo: xi: areg revsignsue treat posrevq_1 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr i.famafrench, a(analys) cl(permno)
eststo: xi: reg2hdfe revsignsue treat posrevq_1 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr, id1(permno) id2(analys) maxiter(5) cluster(permno)
esttab using table6.tex, se r2 nolines nogaps nomtitles noconst label b(%5.3f) se(%5.3f) append keep(treat treat2 posrevq_1 pos_2 Ladsueabs size anal volret impliedvol3012w lnbm roa) order(treat treat2 posrevq_1 pos_2 Ladsueabs size anal volret impliedvol3012w lnbm roa) ///
prehead(\begin{table}\caption{FORECAST REVISION - HETEROGENEOUS BEHAVIOR ACROSS ANALYSTS}\begin{scriptsize} ///
\begin{center}\begin{tabular}{l*{6}{c}}\hline&&&&&&\\&\multicolumn{6}{c}{REVISION IN THE SAME DIRECTION AS THE LATEST SUE}\\&[1]&[2]&[3]&[4]&[5]&[6]\\\cmidrule(lr){2-4}\cmidrule(lr){5-7} &&&&&&\\) ///
prefoot(&&&&&& \\ "Fiscal-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Year-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Analyst FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Industry FE & No & Yes & No & No & Yes & No \\" "Stock FE & No & No & Yes & No & No & Yes \\" &&&&&&\\)  ///
postfoot(&&&&&& \\ \hline  "\end{tabular} \end{center} \end{footnotesize} \end{table}\newpage")starlevels("$^{*}$" 0.10 "$^{**}$" 0.05 "$^{***}$" 0.01)alignment(D{.}{.}{-1}) page(dcolumn) nonumber

eststo clear
eststo: xi: areg posrevq negrevq_1 Ladsueabs size anal volret lnbm roa i.qn i.fqtr if Ladsue>0, a(analys) cl(permno)
eststo: xi: areg posrevq negrevq_1 Ladsueabs size anal volret lnbm roa i.qn i.fqtr i.famafrench if Ladsue>0, a(analys) cl(permno)
eststo: xi: reg2hdfe posrevq negrevq_1 Ladsueabs size anal volret lnbm roa i.qn i.fqtr if Ladsue>0, id1(permno) id2(analys) maxiter(5) cluster(permno)
eststo: xi: areg posrevq negrevq_1 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr if Ladsue>0, a(analys) cl(permno)
eststo: xi: areg posrevq negrevq_1 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr i.famafrench if Ladsue>0, a(analys) cl(permno)
eststo: xi: reg2hdfe posrevq negrevq_1 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr if Ladsue>0, id1(permno) id2(analys) maxiter(5) cluster(permno)
esttab using table7.tex, se r2 nolines nogaps nomtitles noconst label b(%5.3f) se(%5.3f) append keep(negrevq_1 neg_2 Ladsueabs size anal volret impliedvol3012w lnbm roa) order(negrevq_1 neg_2 Ladsueabs size anal volret impliedvol3012w lnbm roa) ///
prehead(\begin{table}\caption{ POSITIVE REVISION - HETEROGENEOUS BEHAVIOR ACROSS ANALYSTS}\begin{scriptsize} ///
\begin{center}\begin{tabular}{l*{6}{c}}\hline&&&&&&\\&\multicolumn{6}{c}{POSREV(Q) (Sample with SUE(Q-1)>0 only)}\\&[1]&[2]&[3]&[4]&[5]&[6]\\\cmidrule(lr){2-4}\cmidrule(lr){5-7} &&&&&&\\) ///
prefoot(&&&&&& \\ "Fiscal-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Year-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Analyst FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Industry FE & No & Yes & No & No & Yes & No \\" "Stock FE & No & No & Yes & No & No & Yes \\" &&&&&&\\)  ///
postfoot(&&&&&& \\ \hline  "\end{tabular} \end{center} \end{footnotesize} \end{table}\newpage")starlevels("$^{*}$" 0.10 "$^{**}$" 0.05 "$^{***}$" 0.01)alignment(D{.}{.}{-1}) page(dcolumn) nonumber

eststo clear
eststo: xi: areg negrevq posrevq_1 Ladsueabs size anal volret lnbm roa i.qn i.fqtr if Ladsue<0, a(analys) cl(permno)
eststo: xi: areg negrevq posrevq_1 Ladsueabs size anal volret lnbm roa i.qn i.fqtr i.famafrench if Ladsue<0, a(analys) cl(permno)
eststo: xi: reg2hdfe negrevq posrevq_1 Ladsueabs size anal volret lnbm roa i.qn i.fqtr if Ladsue<0, id1(permno) id2(analys) maxiter(5) cluster(permno)
eststo: xi: areg negrevq posrevq_1 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr if Ladsue<0, a(analys) cl(permno)
eststo: xi: areg negrevq posrevq_1 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr i.famafrench if Ladsue<0, a(analys) cl(permno)
eststo: xi: reg2hdfe negrevq posrevq_1 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr if Ladsue<0, id1(permno) id2(analys) maxiter(5) cluster(permno)
esttab using table8.tex, se r2 nolines nogaps nomtitles noconst label b(%5.3f) se(%5.3f) append keep(posrevq_1 pos_2 Ladsueabs size anal volret impliedvol3012w lnbm roa) order(posrevq_1 pos_2 Ladsueabs size anal volret impliedvol3012w lnbm roa) ///
prehead(\begin{table}\caption{ NEGATIVE REVISION - HETEROGENEOUS BEHAVIOR ACROSS ANALYSTS}\begin{scriptsize} ///
\begin{center}\begin{tabular}{l*{6}{c}}\hline&&&&&&\\&\multicolumn{6}{c}{NEGREV(Q) (Sample with SUE(Q-1)<0 only)}\\&[1]&[2]&[3]&[4]&[5]&[6]\\\cmidrule(lr){2-4}\cmidrule(lr){5-7} &&&&&&\\) ///
prefoot(&&&&&& \\ "Fiscal-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Year-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Analyst FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Industry FE & No & Yes & No & No & Yes & No \\" "Stock FE & No & No & Yes & No & No & Yes \\" &&&&&&\\)  ///
postfoot(&&&&&& \\ \hline  "\end{tabular} \end{center} \end{footnotesize} \end{table}\newpage")starlevels("$^{*}$" 0.10 "$^{**}$" 0.05 "$^{***}$" 0.01)alignment(D{.}{.}{-1}) page(dcolumn) nonumber


eststo clear
eststo: xi: reg disp change2 Ladsueabs size anal volret lnbm roa i.qn i.fqtr if a==1, cl(permno)
eststo: xi: areg disp change2 Ladsueabs size anal volret lnbm roa i.qn i.fqtr if a==1, a(famafrench) cl(permno)
eststo: xi: areg disp change2 Ladsueabs size anal volret lnbm roa i.qn i.fqtr if a==1, a(permno) cl(permno)
eststo: xi: reg disp change Ladsueabs size anal volret lnbm roa i.qn i.fqtr if a==1, cl(permno)
eststo: xi: areg disp change Ladsueabs size anal volret lnbm roa i.qn i.fqtr if a==1, a(famafrench) cl(permno)
eststo: xi: areg disp change Ladsueabs size anal volret lnbm roa i.qn i.fqtr if a==1, a(permno) cl(permno)
esttab using table9.tex, se r2 nolines nogaps nomtitles noconst label b(%5.3f) se(%5.3f) replace keep(change2 change Ladsueabs size anal volret lnbm roa) order(change2 change Ladsueabs size anal volret lnbm roa) ///
prehead(\begin{table}\caption{ DISPERSION IN ANALYST FORECASTS}\begin{footnotesize} ///
\begin{center}\begin{tabular}{l*{6}{c}}\hline&&&&&&\\&\multicolumn{6}{c}{DISP(Q)}\\&[1]&[2]&[3]&[4]&[5]&[6]\\\cmidrule(lr){2-4}\cmidrule(lr){5-7} &&&&&&\\) ///
prefoot(&&&&&& \\ "Fiscal-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Year-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Industry FE & No & Yes & No & No & Yes & No \\" "Stock FE & No & No & Yes & No & No & Yes \\" &&&&&&\\)  ///
postfoot(&&&&&& \\ \hline  "\end{tabular} \end{center} \end{footnotesize} \end{table}\newpage")starlevels("$^{*}$" 0.10 "$^{**}$" 0.05 "$^{***}$" 0.01)alignment(D{.}{.}{-1}) page(dcolumn) nonumber

eststo clear
eststo: xi: reg disp change2 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr if a==1, cl(permno)
eststo: xi: areg disp change2 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr if a==1, a(famafrench) cl(permno)
eststo: xi: areg disp change2 Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr if a==1, a(permno) cl(permno)
eststo: xi: reg disp change Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr if a==1, cl(permno)
eststo: xi: areg disp change Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr if a==1, a(famafrench) cl(permno)
eststo: xi: areg disp change Ladsueabs size anal impliedvol3012w lnbm roa i.qn i.fqtr if a==1, a(permno) cl(permno)
esttab using table10.tex, se r2 nolines nogaps nomtitles noconst label b(%5.3f) se(%5.3f) append keep(change2 change Ladsueabs size anal impliedvol3012w lnbm roa) order(change2 change Ladsueabs size anal impliedvol3012w lnbm roa) ///
prehead(\begin{table}\caption{ DISPERSION IN ANALYST FORECASTS - ROBUSTNESS}\begin{footnotesize} ///
\begin{center}\begin{tabular}{l*{6}{c}}\hline&&&&&&\\\cmidrule(lr){2-4}\cmidrule(lr){5-7} &&&&&&\\) ///
prefoot(&&&&&& \\ "Fiscal-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Year-Quarter FE & Yes & Yes & Yes & Yes & Yes & Yes \\" "Industry FE & No & Yes & No & No & Yes & No \\" "Stock FE & No & No & Yes & No & No & Yes \\" &&&&&&\\)  ///
postfoot(&&&&&& \\ \hline  "\end{tabular} \end{center} \end{footnotesize} \end{table}\newpage")starlevels("$^{*}$" 0.10 "$^{**}$" 0.05 "$^{***}$" 0.01)alignment(D{.}{.}{-1}) page(dcolumn) nonumber







